@@ -50,6 +50,7 @@ class BaseAPI:
         #     self.__set_token(working_token)
         # else:
         #     self.__get_access_token()
+        self.__last_data = None
 
     def check_status_code_token(self, code: Union[str, int]):
         if str(code) == "401":
@@ -83,14 +84,16 @@ class BaseAPI:
 
     @property
     def organizations_ids_models(self) -> Optional[List[OrganizationModel]]:
-        """Вывести сессию"""
         return self.__organizations_ids_model
 
     @property
     def organizations_ids(self) -> Optional[List[str]]:
-        """Вывести сессию"""
-        return self.__organizations_ids
 
+        return self.__organizations_ids
+    @property
+    def last_data(self) -> Optional[List[str]]:
+
+        return self.__last_data
     @property
     def session_s(self) -> requests.Session:
         """Вывести сессию"""
@@ -178,8 +181,8 @@ class BaseAPI:
                                        headers=self.headers)
         response_data: dict = json.loads(response.content)
         if self.__debug:
-            print(f"{response.status_code=}\n{response_data=}\n")
-
+            print(f"Входные данные:\n{response.request.url=}\n{response.request.body=}\n{response.request.headers=}\n\nВыходные данные:\n{response.headers=}\n{response_data=}\n\n")
+        self.__last_data = response_data
         if response_data.get("errorDescription", None) is not None:
             error_model = model_error.parse_obj(response_data)
             error_model.status_code = response.status_code
@@ -237,7 +240,7 @@ class BaseAPI:
 
 
 class Commands(BaseAPI):
-    def status(self, organization_id: str, correlation_id: str) -> Union[CustomErrorModel,]:
+    def status(self, organization_id: str, correlation_id: str) -> Union[BaseStatusModel, CustomErrorModel,]:
         """
 
         :param organization_id:
@@ -245,7 +248,7 @@ class Commands(BaseAPI):
         :return:
         """
         data = {
-            "organizationIds": organization_id,
+            "organizationId": organization_id,
             "correlationId": correlation_id,
         }
 
